@@ -124,7 +124,7 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
     # Load web servers
     if len(env.roledefs['web_servers'])==0:
         with hide('everything'):
-            execute('web_server', *deploy_settings.get('WEB_SERVERS'))
+            execute('server.web_server', *deploy_settings.get('WEB_SERVERS'))
             if verbose!=0: puts('')
     if len(env.roledefs['web_servers'])==0:
         abort('Where do you want to deploy to?')
@@ -445,6 +445,19 @@ def deploy_to_remote():
         rsync_argument=rsync_argument
     ))
 
+    # Setup Remote
+    if deploy_settings.get('RUN_REMOTE_SETUP'):
+        remote_setup_path = deploy_settings.get('REMOTE_SETUP_SCRIPT', os.path.join(remote_project_source_root, project_name, 'remote_setup.py'))
+        print(cyan('Setup remote'))
+        if target_file_existence(remote_setup_path):
+            target_run('chmod u+x %s'%remote_setup_path)
+            remote_setup_dir, remote_setup_filename = os.path.split(remote_setup_path)
+            with target_cd(remote_setup_dir):
+                target_run('./%s'%remote_setup_filename)
+            target_run('chmod u-x %s'%remote_setup_path)
+        else:
+            print(yellow('Cannot find remote setup script'))
+
     # Copy gitignore
     with target_cd(remote_project_path):
         target_run(rsync('%s/.gitignore'%source_root_name, '.gitignore'))
